@@ -100,6 +100,9 @@ INSTALLED_APPS = (
     'django.contrib.messages',
     'sentry',
     'sentry.client',
+    'sentry.plugins.sentry_redmine',
+    'sentry.plugins.sentry_servers',
+    'sentry.plugins.sentry_urls',
     'paging',
     'south',
     'indexer',
@@ -121,6 +124,7 @@ SENTRY_FILTERS = (
     'example_project.filters.IPFilter',
 )
 SENTRY_SITE = 'example'
+SENTRY_PUBLIC = True
 
 try:
     import debug_toolbar
@@ -134,3 +138,9 @@ else:
     MIDDLEWARE_CLASSES = MIDDLEWARE_CLASSES + (
         'debug_toolbar.middleware.DebugToolbarMiddleware',
     )
+
+try:
+    from local_settings import *
+except ImportError, e:
+    print e
+    pass
\ No newline at end of file
