@@ -1,8 +1,8 @@
 from django import template
 from django.db.models import Count
-from django.utils import simplejson
 
 from sentry.helpers import get_db_engine
+from sentry.plugins import GroupActionProvider
 
 import datetime
 try:
@@ -14,7 +14,7 @@ register = template.Library()
 
 def is_dict(value):
     return isinstance(value, dict)
-is_dict = register.filter(is_dict)
+register.filter(is_dict)
 
 def with_priority(result_list, key='score'):
     if result_list:
@@ -38,16 +38,16 @@ def with_priority(result_list, key='score'):
             else:
                 priority = 'verylow'
             yield result, priority
-with_priority = register.filter(with_priority)
+register.filter(with_priority)
 
 def num_digits(value):
     return len(str(value))
-num_digits = register.filter(num_digits)
+register.filter(num_digits)
 
 def can_chart(group):
     engine = get_db_engine()
     return SimpleLineChart and not engine.startswith('sqlite')
-can_chart = register.filter(can_chart)
+register.filter(can_chart)
 
 def chart_url(group):
     today = datetime.datetime.now()
@@ -73,9 +73,35 @@ def chart_url(group):
     chart.set_colours(['eeeeee', '999999', 'eeeeee'])
     chart.set_line_style(1, 1)
     return chart.get_url()
-chart_url = register.filter(chart_url)
+register.filter(chart_url)
 
 def sentry_version():
-    import sentry
-    return '.'.join(map(str, sentry.__version__))
-sentry_version = register.simple_tag(sentry_version)
\ No newline at end of file
+    from sentry import get_version
+    return get_version()
+register.simple_tag(sentry_version)
+
+def get_actions(group, request):
+    action_list = []
+    for cls in GroupActionProvider.plugins.itervalues():
+        inst = cls(group.pk)
+        action_list = inst.actions(request, action_list, group)
+    for action in action_list:
+        yield action[0], action[1], request.META['PATH_INFO'] == action[1]
+register.filter(get_actions)
+
+def get_panels(group, request):
+    panel_list = []
+    for cls in GroupActionProvider.plugins.itervalues():
+        inst = cls(group.pk)
+        panel_list = inst.panels(request, panel_list, group)
+    for panel in panel_list:
+        yield panel[0], panel[1], request.META['PATH_INFO'] == panel[1]
+register.filter(get_panels)
+
+def get_widgets(group, request):
+    for cls in GroupActionProvider.plugins.itervalues():
+        inst = cls(group.pk)
+        resp = inst.widget(request, group)
+        if resp:
+            yield resp
+register.filter(get_widgets)
\ No newline at end of file
