@@ -11,9 +11,11 @@ import os.path
 import sys
 import threading
 
+from django.conf import settings
 from django.contrib.auth.models import User
 from django.core import mail
 from django.core.handlers.wsgi import WSGIRequest, WSGIHandler
+from django.core.management import call_command
 from django.core.urlresolvers import reverse
 from django.core.signals import got_request_exception
 from django.core.servers import basehttp
@@ -21,16 +23,19 @@ from django.test.client import Client
 from django.test import TestCase
 from django.template import TemplateSyntaxError
 from django.utils.encoding import smart_unicode
-from django.utils import simplejson
 
-from sentry import settings
+from sentry import conf
 from sentry.helpers import transform
 from sentry.models import Message, GroupedMessage
 from sentry.client.base import SentryClient
+from sentry.client.handlers import SentryHandler
 from sentry.client.models import sentry_exception_handler, get_client
 
 from models import TestModel, DuplicateKeyModel
 
+logger = logging.getLogger('sentry.test')
+logger.addHandler(SentryHandler())
+
 class TestServerThread(threading.Thread):
     """Thread for running a http server while tests are running."""
 
@@ -44,7 +49,6 @@ class TestServerThread(threading.Thread):
 
     def run(self):
         """Sets up test server and database and loops over handling http requests."""
-        from django.conf import settings
         try:
             handler = basehttp.AdminMediaHandler(WSGIHandler())
             server_address = (self.address, self.port)
@@ -86,29 +90,11 @@ def conditional_on_module(module):
         return inner
     return wrapped
 
-class RequestFactory(Client):
-    # Used to generate request objects.
-    def request(self, **request):
-        environ = {
-            'HTTP_COOKIE': self.cookies,
-            'PATH_INFO': '/',
-            'QUERY_STRING': '',
-            'REQUEST_METHOD': 'GET',
-            'SCRIPT_NAME': '',
-            'SERVER_NAME': 'testserver',
-            'SERVER_PORT': 80,
-            'SERVER_PROTOCOL': 'HTTP/1.1',
-        }
-        environ.update(self.defaults)
-        environ.update(request)
-        return WSGIRequest(environ)
- 
-RF = RequestFactory()
-
 class SentryTestCase(TestCase):
     urls = 'sentry.tests.urls'
 
     def setUp(self):
+        self._middleware = settings.MIDDLEWARE_CLASSES
         self._handlers = None
         self._level = None
         self.logger = logging.getLogger('sentry')
@@ -118,10 +104,10 @@ class SentryTestCase(TestCase):
 
     def tearDown(self):
         self.tearDownHandler()
+        settings.MIDDLEWARE_CLASSES = self._middleware
         
     def setUpHandler(self):
         self.tearDownHandler()
-        from sentry.client.handlers import SentryHandler
         
         logger = logging.getLogger()
         self._handlers = logger.handlers
@@ -201,30 +187,23 @@ class SentryTestCase(TestCase):
             self.assertEquals(last.class_name, 'ValueError')
             self.assertEquals(last.message, 'This is a test info with an exception')
             self.assertTrue(last.data.get('__sentry__', {}).get('exc'))
-    
-        self.tearDownHandler()
-    
-    def testMiddleware(self):
-        Message.objects.all().delete()
-        GroupedMessage.objects.all().delete()
-        
-        request = RF.get("/", REMOTE_ADDR="127.0.0.1:8000")
 
-        try:
-            Message.objects.get(id=999999999)
-        except Message.DoesNotExist, exc:
-            sentry_exception_handler(request=request, sender=self)
-        else:
-            self.fail('Unable to create `Message` entry.')
-        
-        self.assertEquals(Message.objects.count(), 1)
-        self.assertEquals(GroupedMessage.objects.count(), 1)
-        last = Message.objects.get()
-        self.assertEquals(last.logger, 'root')
-        self.assertEquals(last.class_name, 'DoesNotExist')
-        self.assertEquals(last.level, logging.ERROR)
-        self.assertEquals(last.message, smart_unicode(exc))
-        
+        self.tearDownHandler()
+
+    # def test404Middleware(self):
+    #     settings.MIDDLEWARE_CLASSES = settings.MIDDLEWARE_CLASSES + ('sentry.client.middleware.Sentry404CatchMiddleware',)
+    #     
+    #     response = self.client.get("/404/this-page-does-not-exist", REMOTE_ADDR="127.0.0.1:8000")
+    #     self.assertTemplateUsed(response, '404.html')
+    #     
+    #     self.assertEquals(Message.objects.count(), 1)
+    #     self.assertEquals(GroupedMessage.objects.count(), 1)
+    #     last = Message.objects.get()
+    #     self.assertEquals(last.logger, 'root')
+    #     self.assertEquals(last.class_name, 'Http404')
+    #     self.assertEquals(last.level, logging.ERROR)
+    #     self.assertEquals(last.message, 'foo')
+
     def testAPI(self):
         try:
             Message.objects.get(id=999999989)
@@ -260,7 +239,7 @@ class SentryTestCase(TestCase):
         self.assertEquals(last.message, 'This is an error')
         
     def testAlternateDatabase(self):
-        settings.DATABASE_USING = 'default'
+        conf.DATABASE_USING = 'default'
         
         try:
             Message.objects.get(id=999999979)
@@ -277,7 +256,7 @@ class SentryTestCase(TestCase):
         self.assertEquals(last.level, logging.ERROR)
         self.assertEquals(last.message, smart_unicode(exc))
 
-        settings.DATABASE_USING = None
+        conf.DATABASE_USING = None
     
     def testIncorrectUnicode(self):
         self.setUpHandler()
@@ -338,8 +317,8 @@ class SentryTestCase(TestCase):
         self.assertEquals(error.data['url'], 'a'*210)
     
     def testThrashing(self):
-        settings.THRASHING_LIMIT = 10
-        settings.THRASHING_TIMEOUT = 60
+        conf.THRASHING_LIMIT = 10
+        conf.THRASHING_TIMEOUT = 60
         
         Message.objects.all().delete()
         GroupedMessage.objects.all().delete()
@@ -347,15 +326,13 @@ class SentryTestCase(TestCase):
         for i in range(0, 50):
             get_client().create_from_text('hi')
         
-        self.assertEquals(Message.objects.count(), settings.THRASHING_LIMIT)
+        self.assertEquals(Message.objects.count(), conf.THRASHING_LIMIT)
     
     def testSignals(self):
-        request = RF.get("/", REMOTE_ADDR="127.0.0.1:8000")
-
         try:
             Message.objects.get(id=999999999)
         except Message.DoesNotExist, exc:
-            got_request_exception.send(sender=self.__class__, request=request)
+            got_request_exception.send(sender=self.__class__, request=None)
         else:
             self.fail('Expected an exception.')
             
@@ -368,8 +345,6 @@ class SentryTestCase(TestCase):
         self.assertEquals(last.message, smart_unicode(exc))
 
     def testSignalsWithoutRequest(self):
-        request = RF.get("/", REMOTE_ADDR="127.0.0.1:8000")
-
         try:
             Message.objects.get(id=999999999)
         except Message.DoesNotExist, exc:
@@ -386,8 +361,8 @@ class SentryTestCase(TestCase):
         self.assertEquals(last.message, smart_unicode(exc))
 
     def testNoThrashing(self):
-        prev = settings.THRASHING_LIMIT
-        settings.THRASHING_LIMIT = 0
+        prev = conf.THRASHING_LIMIT
+        conf.THRASHING_LIMIT = 0
         
         Message.objects.all().delete()
         GroupedMessage.objects.all().delete()
@@ -397,7 +372,7 @@ class SentryTestCase(TestCase):
         
         self.assertEquals(Message.objects.count(), 50)
 
-        settings.THRASHING_LIMIT = prev
+        conf.THRASHING_LIMIT = prev
 
     def testDatabaseMessage(self):
         from django.db import connection
@@ -436,7 +411,6 @@ class SentryTestCase(TestCase):
         self.assertEquals(last.view, 'sentry.tests.views.raise_exc')
 
     def testRequestMiddlwareException(self):
-        from django.conf import settings
         orig = list(settings.MIDDLEWARE_CLASSES)
         settings.MIDDLEWARE_CLASSES = orig + ['sentry.tests.middleware.BrokenRequestMiddleware',]
         
@@ -454,7 +428,6 @@ class SentryTestCase(TestCase):
 
     # XXX: Django doesn't handle response middleware exceptions (yet)
     # def testResponseMiddlwareException(self):
-    #     from django.conf import settings
     #     orig = list(settings.MIDDLEWARE_CLASSES)
     #     settings.MIDDLEWARE_CLASSES = orig + ['sentry.tests.middleware.BrokenResponseMiddleware',]
     #     
@@ -471,7 +444,6 @@ class SentryTestCase(TestCase):
     #     settings.MIDDLEWARE_CLASSES = orig
 
     def testViewMiddlewareException(self):
-        from django.conf import settings
         orig = list(settings.MIDDLEWARE_CLASSES)
         settings.MIDDLEWARE_CLASSES = orig + ['sentry.tests.middleware.BrokenViewMiddleware',]
         
@@ -488,10 +460,10 @@ class SentryTestCase(TestCase):
         settings.MIDDLEWARE_CLASSES = orig
 
     def testSettingName(self):
-        orig_name = settings.NAME
-        orig_site = settings.SITE
-        settings.NAME = 'foo'
-        settings.SITE = 'bar'
+        orig_name = conf.NAME
+        orig_site = conf.SITE
+        conf.NAME = 'foo'
+        conf.SITE = 'bar'
         
         self.assertRaises(Exception, self.client.get, reverse('sentry-raise-exc'))
 
@@ -506,8 +478,8 @@ class SentryTestCase(TestCase):
         self.assertEquals(last.site, 'bar')
         self.assertEquals(last.view, 'sentry.tests.views.raise_exc')
         
-        settings.NAME = orig_name
-        settings.SITE = orig_site
+        conf.NAME = orig_name
+        conf.SITE = orig_site
 
     def testExclusionViewPath(self):
         try: Message.objects.get(pk=1341324)
@@ -518,7 +490,7 @@ class SentryTestCase(TestCase):
         self.assertEquals(last.view, 'sentry.tests.tests.testExclusionViewPath')
 
     def testBestGuessView(self):
-        settings.EXCLUDE_PATHS = ['sentry.tests.tests']
+        conf.EXCLUDE_PATHS = ['sentry.tests.tests']
         
         try: Message.objects.get(pk=1341324)
         except: get_client().create_from_exception()
@@ -527,10 +499,10 @@ class SentryTestCase(TestCase):
         
         self.assertEquals(last.view, 'sentry.tests.tests.testBestGuessView')
         
-        settings.EXCLUDE_PATHS = []
+        conf.EXCLUDE_PATHS = []
 
     def testExcludeModulesView(self):
-        settings.EXCLUDE_PATHS = ['sentry.tests.views.decorated_raise_exc']
+        conf.EXCLUDE_PATHS = ['sentry.tests.views.decorated_raise_exc']
         
         self.assertRaises(Exception, self.client.get, reverse('sentry-raise-exc-decor'))
         
@@ -538,7 +510,7 @@ class SentryTestCase(TestCase):
         
         self.assertEquals(last.view, 'sentry.tests.views.raise_exc')
         
-        settings.EXCLUDE_PATHS = []
+        conf.EXCLUDE_PATHS = []
 
     def testVaryingMessages(self):
         self.assertRaises(Exception, self.client.get, reverse('sentry-raise-exc') + '?message=foo')
@@ -548,7 +520,7 @@ class SentryTestCase(TestCase):
         self.assertEquals(GroupedMessage.objects.count(), 1)
 
     def testIncludeModules(self):
-        settings.INCLUDE_PATHS = ['django.shortcuts.get_object_or_404']
+        conf.INCLUDE_PATHS = ['django.shortcuts.get_object_or_404']
         
         self.assertRaises(Exception, self.client.get, reverse('sentry-django-exc'))
         
@@ -556,7 +528,7 @@ class SentryTestCase(TestCase):
         
         self.assertEquals(last.view, 'django.shortcuts.get_object_or_404')
         
-        settings.INCLUDE_PATHS = []
+        conf.INCLUDE_PATHS = []
 
     def testTemplateNameAsView(self):
         self.assertRaises(TemplateSyntaxError, self.client.get, reverse('sentry-template-exc'))
@@ -565,15 +537,24 @@ class SentryTestCase(TestCase):
         
         self.assertEquals(last.view, 'sentry-tests/error.html')
 
+    def testRequestInLogging(self):
+        resp = self.client.get(reverse('sentry-log-request-exc'))
+        self.assertEquals(resp.status_code, 200)
+        
+        last = Message.objects.get()
+        
+        self.assertEquals(last.view, 'sentry.tests.views.logging_request_exc')
+        self.assertEquals(last.data['META']['REMOTE_ADDR'], '127.0.0.1')
+
 class SentryViewsTest(TestCase):
     urls = 'sentry.tests.urls'
     fixtures = ['sentry/tests/fixtures/views.json']
     
     def setUp(self):
-        settings.DATABASE_USING = None
+        conf.DATABASE_USING = None
         self._handlers = None
         self._level = None
-        settings.DEBUG = False
+        conf.DEBUG = False
         self.user = User(username="admin", email="admin@localhost", is_staff=True, is_superuser=True)
         self.user.set_password('admin')
         self.user.save()
@@ -583,7 +564,6 @@ class SentryViewsTest(TestCase):
         
     def setUpHandler(self):
         self.tearDownHandler()
-        from sentry.client.handlers import SentryHandler
         
         logger = logging.getLogger()
         self._handlers = logger.handlers
@@ -647,7 +627,7 @@ class RemoteSentryTest(TestCase):
     
     def setUp(self):
         self.server_thread = None
-        settings.REMOTE_URL = ['http://localhost:8000%s' % reverse('sentry-store')]
+        conf.REMOTE_URL = ['http://localhost:8000%s' % reverse('sentry-store')]
         logger = logging.getLogger('sentry')
         for h in logger.handlers:
             logger.removeHandler(h)
@@ -655,7 +635,7 @@ class RemoteSentryTest(TestCase):
 
     def tearDown(self):
         self.stop_test_server()
-        settings.REMOTE_URL = None
+        conf.REMOTE_URL = None
 
     def testNoKey(self):
         resp = self.client.post(reverse('sentry-store'))
@@ -664,14 +644,14 @@ class RemoteSentryTest(TestCase):
 
     def testNoData(self):
         resp = self.client.post(reverse('sentry-store'), {
-            'key': settings.KEY,
+            'key': conf.KEY,
         })
         self.assertEquals(resp.status_code, 403)
         self.assertEquals(resp.content, 'Missing data')
 
     def testBadData(self):
         resp = self.client.post(reverse('sentry-store'), {
-            'key': settings.KEY,
+            'key': conf.KEY,
             'data': 'hello world',
         })
         self.assertEquals(resp.status_code, 403)
@@ -681,7 +661,7 @@ class RemoteSentryTest(TestCase):
         kwargs = {'message': 'hello', 'server_name': 'not_dcramer.local', 'level': 40, 'site': 'not_a_real_site'}
         resp = self.client.post(reverse('sentry-store'), {
             'data': base64.b64encode(pickle.dumps(transform(kwargs)).encode('zlib')),
-            'key': settings.KEY,
+            'key': conf.KEY,
         })
         self.assertEquals(resp.status_code, 200)
         instance = Message.objects.get()
@@ -694,7 +674,7 @@ class RemoteSentryTest(TestCase):
         kwargs = {'message': 'hello', 'server_name': 'not_dcramer.local', 'level': 40, 'site': 'not_a_real_site'}
         resp = self.client.post(reverse('sentry-store'), {
             'data': base64.b64encode(pickle.dumps(transform(kwargs))),
-            'key': settings.KEY,
+            'key': conf.KEY,
         })
         self.assertEquals(resp.status_code, 200)
         instance = Message.objects.get()
@@ -715,7 +695,7 @@ class RemoteSentryTest(TestCase):
         
         resp = self.client.post(reverse('sentry-store'), {
             'data': data,
-            'key': settings.KEY,
+            'key': conf.KEY,
         })
         self.assertEquals(resp.status_code, 200)
         instance = Message.objects.get()
@@ -766,7 +746,7 @@ class SentryMailTest(TestCase):
     urls = 'sentry.tests.urls'
     
     def setUp(self):
-        settings.ADMINS = ('%s@localhost' % getpass.getuser(),)
+        conf.ADMINS = ('%s@localhost' % getpass.getuser(),)
     
     def test_mail_admins(self):
         group = GroupedMessage.objects.get()
@@ -781,7 +761,7 @@ class SentryMailTest(TestCase):
         self.assertEquals(out.subject, '[Django] Error (EXTERNAL IP): /group/1')
 
     def test_mail_on_creation(self):
-        settings.MAIL = True
+        conf.MAIL = True
         
         self.assertEquals(len(mail.outbox), 0)
         self.assertRaises(Exception, self.client.get, reverse('sentry-raise-exc'))
@@ -796,7 +776,7 @@ class SentryMailTest(TestCase):
         self.assertEquals(out.subject, '[Django] Error (EXTERNAL IP): /trigger-500')
 
     def test_mail_on_duplication(self):
-        settings.MAIL = True
+        conf.MAIL = True
         
         self.assertEquals(len(mail.outbox), 0)
         self.assertRaises(Exception, self.client.get, reverse('sentry-raise-exc'))
@@ -819,9 +799,18 @@ class SentryMailTest(TestCase):
         self.assertTrue("<Request" in out.body)
         self.assertEquals(out.subject, '[Django] Error (EXTERNAL IP): /trigger-500')
 
+    def test_url_prefix(self):
+        conf.URL_PREFIX = 'http://example.com'
+
+        group = GroupedMessage.objects.get()
+        group.mail_admins(fail_silently=False)
+
+        out = mail.outbox[0]
+
+        self.assertTrue('http://example.com/group/2' in out.body, out.body)
+
 class SentryHelpersTest(TestCase):
     def test_get_db_engine(self):
-        from django.conf import settings
         from sentry.helpers import get_db_engine
         _databases = getattr(settings, 'DATABASES', {}).copy()
         _engine = settings.DATABASE_ENGINE
@@ -846,26 +835,25 @@ class SentryClientTest(TestCase):
     urls = 'sentry.tests.urls'
 
     def setUp(self):
-        self._client = settings.CLIENT
+        self._client = conf.CLIENT
         
     def tearDown(self):
-        settings.CLIENT = self._client
+        conf.CLIENT = self._client
     
     def test_get_client(self):
-        from sentry.client.base import SentryClient
         from sentry.client.log import LoggingSentryClient
         self.assertEquals(get_client().__class__, SentryClient)
         self.assertEquals(get_client(), get_client())
     
-        settings.CLIENT = 'sentry.client.log.LoggingSentryClient'
+        conf.CLIENT = 'sentry.client.log.LoggingSentryClient'
         
         self.assertEquals(get_client().__class__, LoggingSentryClient)
         self.assertEquals(get_client(), get_client())
     
-        settings.CLIENT = 'sentry.client.base.SentryClient'
+        conf.CLIENT = 'sentry.client.base.SentryClient'
     
     def test_logging_client(self):
-        settings.CLIENT = 'sentry.client.log.LoggingSentryClient'
+        conf.CLIENT = 'sentry.client.log.LoggingSentryClient'
         
         client = get_client()
         
@@ -885,12 +873,11 @@ class SentryClientTest(TestCase):
         self.assertEquals(_foo[''].class_name, 'Exception')
 
     def test_celery_client(self):
-        from sentry.client.base import SentryClient
         from sentry.client.celery import CelerySentryClient
         self.assertEquals(get_client().__class__, SentryClient)
         self.assertEquals(get_client(), get_client())
 
-        settings.CLIENT = 'sentry.client.celery.CelerySentryClient'
+        conf.CLIENT = 'sentry.client.celery.CelerySentryClient'
 
         self.assertEquals(get_client().__class__, CelerySentryClient)
         self.assertEquals(get_client(), get_client())
@@ -901,7 +888,7 @@ class SentryClientTest(TestCase):
         self.assertEqual(message.class_name, 'Exception')
         self.assertEqual(message.message, 'view exception')
 
-        settings.CLIENT = 'sentry.client.base.SentryClient'
+        conf.CLIENT = 'sentry.client.base.SentryClient'
         
 class SentryManageTest(TestCase):
     fixtures = ['sentry/tests/fixtures/cleanup.json']
@@ -914,4 +901,4 @@ class SentryManageTest(TestCase):
         command = Command()
         command.handle(days=1)
         
-        self.assertEquals(Message.objects.count(), 0)
+        self.assertEquals(Message.objects.count(), 0)
\ No newline at end of file
