@@ -1,9 +1,8 @@
 import os
 
-from django.conf import settings
 from django.conf.urls.defaults import *
 
-from sentry.settings import KEY
+from sentry.conf import KEY
 from sentry import views
 from sentry.feeds import MessageFeed, SummaryFeed
 
@@ -30,8 +29,7 @@ urlpatterns = patterns('',
     url(r'^group/(\d+)$', views.group, name='sentry-group'),
     url(r'^group/(\d+)/messages$', views.group_message_list, name='sentry-group-messages'),
     url(r'^group/(\d+)/messages/(\d+)$', views.group_message_details, name='sentry-group-message'),
-    url(r'^group/(\d+)/urls$', views.group_urls, name='sentry-group-urls'),
-    url(r'^group/(\d+)/servers$', views.group_servers, name='sentry-group-servers'),
+    url(r'^group/(\d+)/actions/([\w_-]+)', views.group_plugin_action, name='sentry-group-plugin-action'),
 
     url(r'^$', views.index, name='sentry'),
 )
