@@ -4,25 +4,22 @@ try:
 except ImportError:
     import pickle
 import datetime
-from math import log
 import logging
 import zlib
 
-from django.conf import settings as dj_settings
 from django.core.context_processors import csrf
 from django.core.urlresolvers import reverse
-from django.db.models import Count
 from django.http import HttpResponse, HttpResponseBadRequest, \
-    HttpResponseForbidden, HttpResponseRedirect
+    HttpResponseForbidden, HttpResponseRedirect, Http404
 from django.shortcuts import render_to_response, get_object_or_404
 from django.template.loader import render_to_string
 from django.utils import simplejson
-from django.utils.datastructures import SortedDict
 from django.utils.safestring import mark_safe
 from django.views.decorators.csrf import csrf_protect, csrf_exempt
 
-from sentry import settings
+from sentry import conf
 from sentry.models import GroupedMessage, Message
+from sentry.plugins import GroupActionProvider
 from sentry.templatetags.sentry_helpers import with_priority
 from sentry.reporter import ImprovedExceptionReporter
 
@@ -33,15 +30,13 @@ def get_filters():
     global _FILTER_CACHE
     
     if _FILTER_CACHE is None:
-        from sentry import settings
-        
         filters = []
-        for filter_ in settings.FILTERS:
+        for filter_ in conf.FILTERS:
             module_name, class_name = filter_.rsplit('.', 1)
             try:
                 module = __import__(module_name, {}, {}, class_name)
                 filter_ = getattr(module, class_name)
-            except Exception, exc:
+            except Exception:
                 logging.exception('Unable to import %s' % (filter_,))
                 continue
             if filter_.column.startswith('data__'):
@@ -53,10 +48,11 @@ def get_filters():
 
 def login_required(func):
     def wrapped(request, *args, **kwargs):
-        if not request.user.is_authenticated():
-            return HttpResponseRedirect(reverse('sentry-login'))
-        if not request.user.has_perm('sentry_groupedmessage.can_view'):
-            return HttpResponseRedirect(reverse('sentry-login'))
+        if not conf.PUBLIC:
+            if not request.user.is_authenticated():
+                return HttpResponseRedirect(reverse('sentry-login'))
+            if not request.user.has_perm('sentry_groupedmessage.can_view'):
+                return HttpResponseRedirect(reverse('sentry-login'))
         return func(request, *args, **kwargs)
     wrapped.__doc__ = func.__doc__
     wrapped.__name__ = func.__name__
@@ -64,7 +60,7 @@ def login_required(func):
 
 @csrf_protect
 def login(request):
-    from django.contrib.auth import authenticate, login as login_
+    from django.contrib.auth import login as login_
     from django.contrib.auth.forms import AuthenticationForm
     
     if request.POST:
@@ -81,7 +77,7 @@ def login(request):
     
     context = locals()
     context.update(csrf(request))
-    return render_to_response('sentry/login.html', locals(), )
+    return render_to_response('sentry/login.html', locals())
 
 def logout(request):
     from django.contrib.auth import logout
@@ -198,9 +194,7 @@ def ajax_handler(request):
 def group(request, group_id):
     group = get_object_or_404(GroupedMessage, pk=group_id)
 
-    message_list = group.message_set.all()
-    
-    obj = message_list.order_by('-id')[0]
+    obj = group.message_set.all().order_by('-id')[0]
     if '__sentry__' in obj.data:
         module, args, frames = obj.data['__sentry__']['exc']
         obj.class_name = str(obj.class_name)
@@ -223,6 +217,7 @@ def group(request, group_id):
     
     json_data = iter_data(obj)
     
+    page = 'details'
     
     return render_to_response('sentry/group/details.html', locals())
 
@@ -240,8 +235,6 @@ def group_message_list(request, group_id):
 def group_message_details(request, group_id, message_id):
     group = get_object_or_404(GroupedMessage, pk=group_id)
 
-    message_list = group.message_set.all()
-
     message = get_object_or_404(group.message_set, pk=message_id)
     
     if '__sentry__' in message.data:
@@ -270,26 +263,10 @@ def group_message_details(request, group_id, message_id):
     
     return render_to_response('sentry/group/message.html', locals())
 
-@login_required
-def group_urls(request, group_id):
-    group = get_object_or_404(GroupedMessage, pk=group_id)
-
-    page = 'urls'
-    
-    return render_to_response('sentry/group/url_list.html', locals())
-
-@login_required
-def group_servers(request, group_id):
-    group = get_object_or_404(GroupedMessage, pk=group_id)
-
-    page = 'servers'
-    
-    return render_to_response('sentry/group/server_list.html', locals())
-
 @csrf_exempt
 def store(request):
     key = request.POST.get('key')
-    if key != settings.KEY:
+    if key != conf.KEY:
         return HttpResponseForbidden('Invalid credentials')
     
     data = request.POST.get('data')
@@ -298,11 +275,24 @@ def store(request):
     try:
         try:
             data = pickle.loads(base64.b64decode(data).decode('zlib'))
-        except zlib.error, e:
+        except zlib.error:
             data = pickle.loads(base64.b64decode(data))
-    except Exception, e:
+    except Exception:
         return HttpResponseForbidden('Bad data')
 
     GroupedMessage.objects.from_kwargs(**data)
     
     return HttpResponse()
+
+@login_required
+def group_plugin_action(request, group_id, slug):
+    group = get_object_or_404(GroupedMessage, pk=group_id)
+    
+    try:
+        cls = GroupActionProvider.plugins[slug]
+    except KeyError:
+        raise Http404('Plugin not found')
+    response = cls(group_id)(request, group)
+    if response:
+        return response
+    return HttpResponseRedirect(request.META['HTTP_REFERER'])
\ No newline at end of file
